PCB Environment: GridDirection Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Static Public Member Functions | Static Public Attributes
GridDirection Class Reference

## Public Member Functions
constexpr | GridDirection (uint8_t i)
| GridDirection (const IVector_3 &)
uint | n () const
constexpr uint32_t | mask () const
bool | _isDiagonal () const
bool | isDiagonal () const
bool | isZero () const
bool | isVertical () const
bool | is2D () const
bool | operator== (const GridDirection &d) const
GridDirection & | operator++ ()
GridDirection & | operator= (const GridDirection &d)
int | dx () const
int | dy () const
int | dz () const
IVector_3 | ivec3 () const
Vector_2 | vec2 () const
int | deg () const
GridDirection | opposite () const
GridDirection | rotatedCcw45 (uint n=1) const
GridDirection | rotatedCw45 (uint n=1) const
GridDirection | rotatedCcw (int degrees) const
uint8_t | get45DegreeStepsBetween (const GridDirection &d) const
const char * | str () const

## Static Public Member Functions
static GridDirection | Degrees (int)
static GridDirection | fromSigns (const Vector_2 &, Real zeroThreshold=0x1.0p-10)
static constexpr GridDirection | begin ()
static constexpr GridDirection | hend ()
static constexpr GridDirection | vend ()
static constexpr GridDirection | U ()
static constexpr GridDirection | UR ()
static constexpr GridDirection | R ()
static constexpr GridDirection | DR ()
static constexpr GridDirection | D ()
static constexpr GridDirection | DL ()
static constexpr GridDirection | L ()
static constexpr GridDirection | UL ()
static constexpr GridDirection | A ()
static constexpr GridDirection | V ()
static constexpr GridDirection | Z ()

## Static Public Attributes
static constexpr const uint | FirstVertical = 8
static constexpr const uint | Count = 10
static const int | dXYZ [11][3]
static const Vector_2 | sVec [11]
static const uint8_t | sOpposites [11]
static const char * | sStrings [11]

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/GridDirection.hpp